@@ -1,7 +1,7 @@
 /* -*- mode:C; coding:utf-8 -*- */
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2023  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2025  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -29,11 +29,11 @@ extern "C" {
 #endif
 
 /* This is the minimum hdf version med must have  */
-#define HDF_VERSION_REF "2.0.0"
-#define HDF_VERSION_MAJOR_REF 2
-#define HDF_VERSION_MINOR_REF 0
-#define HDF_VERSION_RELEASE_REF 0
-#define HDF_VERSION_NUM_REF (HDF_VERSION_MAJOR_REF * 10000 + HDF_VERSION_MINOR_REF * 100  + HDF_VERSION_RELEASE_REF )
+#define HDF_VERSION_REF         "1.14.6"
+#define HDF_VERSION_MAJOR_REF   1
+#define HDF_VERSION_MINOR_REF   14
+#define HDF_VERSION_RELEASE_REF 6
+#define HDF_VERSION_NUM_REF     (HDF_VERSION_MAJOR_REF * 10000 + HDF_VERSION_MINOR_REF * 100  + HDF_VERSION_RELEASE_REF )
 
 #define HDF5_VERSION (H5_VERS_MAJOR * 10000 + H5_VERS_MINOR * 100  + H5_VERS_RELEASE )
 
@@ -54,19 +54,25 @@ extern "C" {
 #endif
 
 /*En anglais*/
-#define MED_MAJOR_NUM 5
-#define MED_MINOR_NUM 0
-#define MED_RELEASE_NUM 0
-#define MED_3_LATEST_MINOR 3
-#define MED_4_LATEST_MINOR 1
-#define MED_40_LATEST_RELEASE @MED_40_LATEST_RELEASE@
-#define MED_5_LATEST_MINOR 0
-#define MED_50_LATEST_RELEASE 0
+#define MED_MAJOR_NUM  6
+#define MED_MINOR_NUM  0
+#define MED_RELEASE_NUM 1
+  
+#define MED_3_LATEST_MINOR    3
+#define MED_4_LATEST_MINOR    2
+#define MED_40_LATEST_RELEASE 1
+#define MED_41_LATEST_RELEASE 2
+#define MED_42_LATEST_RELEASE @MED_42_LATEST_RELEASE@
+#define MED_5_LATEST_MINOR    1
+#define MED_50_LATEST_RELEASE 2
+#define MED_51_LATEST_RELEASE 0
+#define MED_6_LATEST_MINOR    0
+#define MED_60_LATEST_RELEASE 1
 
 /*En franglais*/
-#define MED_NUM_MAJEUR 5
-#define MED_NUM_MINEUR 0
-#define MED_NUM_RELEASE 0
+#define MED_NUM_MAJEUR  6
+#define MED_NUM_MINEUR  0
+#define MED_NUM_RELEASE 1
 
 #define STR(x) #x
 #define _MED_VERSION(x,y,z) STR(x) "." STR(y) "." STR(z)
@@ -75,18 +81,20 @@ extern "C" {
 
 
 #define MED_NULL       (void *) NULL
-#define MED_MAX_PARA        20
+#define MED_MAX_PARA   20
 
 /** Longueurs des chaînes de caractères stockées dans les fichiers */
 #define MED_COMMENT_SIZE 200
-#define MED_IDENT_SIZE 8
-#define MED_NAME_SIZE 64
-#define MED_SNAME_SIZE 16
-#define MED_LNAME_SIZE 80
+#define MED_IDENT_SIZE     8
+#define MED_NAME_SIZE     64
+#define MED_SNAME_SIZE    16
+#define MED_LNAME_SIZE    80
 
 #define MED_SNAME_BLANK "                "
 #define MED_NAME_BLANK  "                                                                "
 /*                       0123456789012345678901234567890123456789012345678901234567890123*/
+#define MED_LNAME_BLANK  MED_NAME_BLANK MED_SNAME_BLANK
+
 
 #define MED_PATHNAME_SIZE 255
 #define MED_MAX_CHFID_PATH MED_PATHNAME_SIZE  /**< Taille maximum du chemin d'accès au groupe cible pour MEDfileObjectsMountById */
@@ -96,24 +104,24 @@ extern "C" {
 */
 /* 2.3v3.0 ok*/
 typedef enum {MED_FULL_INTERLACE, /**<Exemple avec 3 composantes X,Y,Z : X1Y1Z1X2Y2Z2X3Y3Z3...
-				      Exemple avec 3 MED_TRIA3 T1,T2,T3 : N11N12N13 N21N22N23 N31N32N33 */
-	      MED_NO_INTERLACE,    /**<Exemple avec 3 composantes X,Y,Z : X1X2X3Y1Y2Y3Z1Z2Z3...
-				       Exemple avec 3 MED_TRIA3 T1,T2,T3 : N11N21N31 N12N22N32 N13N23N33 */
+                                      Exemple avec 3 MED_TRIA3 T1,T2,T3 : N11N12N13 N21N22N23 N31N32N33 */
+              MED_NO_INTERLACE,    /**<Exemple avec 3 composantes X,Y,Z : X1X2X3Y1Y2Y3Z1Z2Z3...
+                                       Exemple avec 3 MED_TRIA3 T1,T2,T3 : N11N21N31 N12N22N32 N13N23N33 */
               MED_UNDEF_INTERLACE=-1/**<Mode d'entelacement non défini */
-	}  med_switch_mode;
-
+        }  med_switch_mode;
+#define med_interlacing_mode med_switch_mode
 
 /**\enum med_storage_mode Mode de stockage global ou compact.
    \details Indique le mode de stockage utilisé par l'application.
 */
 /* 2.3v3.0 ok*/
-typedef enum { MED_UNDEF_STMODE,  /**< Mode de stockage en mémoire non initialisé*/
-               MED_GLOBAL_STMODE, /**< Le stockage utilisé contient en mémoire toutes les valeurs relatives à toutes les entités d'un même type.*/ 
-	       MED_COMPACT_STMODE, /**< Le stockage utilisé contient en mémoire contigüe un sous-ensemble de valeurs relatives à un sous-ensemble d'entités d'un même type.*/ 
+typedef enum { MED_UNDEF_STMODE,   /**< Mode de stockage en mémoire non initialisé*/
+               MED_GLOBAL_STMODE,  /**< Le stockage utilisé contient en mémoire toutes les valeurs relatives à toutes les entités d'un même type.*/ 
+               MED_COMPACT_STMODE, /**< Le stockage utilisé contient en mémoire contigüe un sous-ensemble de valeurs relatives à un sous-ensemble d'entités d'un même type.*/ 
                MED_GLOBAL_PFLMODE=MED_GLOBAL_STMODE,   /**< Old name, do not use it anymore*/
                MED_COMPACT_PFLMODE=MED_COMPACT_STMODE, /**< Old name, do not use it anymore*/
                MED_UNDEF_PFLMODE=MED_UNDEF_STMODE      /**< Old name, do not use it anymore*/
-	     }  med_storage_mode;
+             }  med_storage_mode;
 
 
 /**\enum med_access_mode
@@ -137,60 +145,61 @@ typedef enum {MED_UNSTRUCTURED_MESH, MED_STRUCTURED_MESH, MED_UNDEF_MESH_TYPE=-1
 */
 /* 2.3v3.0 ok*/
 typedef enum {MED_CARTESIAN_GRID,
-	      MED_POLAR_GRID,
-	      MED_CURVILINEAR_GRID,
-	      MED_UNDEF_GRID_TYPE=-1} med_grid_type;
+              MED_POLAR_GRID,
+              MED_CURVILINEAR_GRID,
+              MED_UNDEF_GRID_TYPE=-1} med_grid_type;
 
 /* 2.3v3.0 ok*/
 typedef enum {MED_CELL, MED_DESCENDING_FACE, MED_DESCENDING_EDGE, MED_NODE,
-	      MED_NODE_ELEMENT, MED_STRUCT_ELEMENT, MED_ALL_ENTITY_TYPE,
-	      MED_UNDEF_ENTITY_TYPE=-1 } med_entity_type;
+              MED_NODE_ELEMENT, MED_STRUCT_ELEMENT, MED_ALL_ENTITY_TYPE,
+              MED_UNDEF_ENTITY_TYPE=-1 } med_entity_type;
 #define MED_N_ENTITY_TYPES 6
 
 /* 2.3v3.0 ok*/
 typedef enum {MED_COORDINATE, MED_CONNECTIVITY, MED_NAME, MED_NUMBER,  MED_FAMILY_NUMBER, 
-	MED_COORDINATE_AXIS1, MED_COORDINATE_AXIS2, MED_COORDINATE_AXIS3, 
-	MED_INDEX_FACE, MED_INDEX_NODE, MED_GLOBAL_NUMBER,
-	MED_VARIABLE_ATTRIBUTE, MED_COORDINATE_TRSF,MED_UNDEF_DATATYPE=-1} med_data_type;
+        MED_COORDINATE_AXIS1, MED_COORDINATE_AXIS2, MED_COORDINATE_AXIS3, 
+        MED_INDEX_FACE, MED_INDEX_NODE, MED_GLOBAL_NUMBER,
+        MED_VARIABLE_ATTRIBUTE, MED_COORDINATE_TRSF,MED_UNDEF_DATATYPE=-1} med_data_type;
 
 /* 2.3v3.0 ok*/
 /** \internal*/
 typedef enum {MED_INTERNAL_FLOAT32=4, MED_INTERNAL_FLOAT64=6,
-	      MED_INTERNAL_INT8=20,
-	      MED_INTERNAL_INT32=24 , MED_INTERNAL_INT64=26, MED_INTERNAL_INT=28,
-	      MED_INTERNAL_NAME=30  , MED_INTERNAL_SNAME=32,
-	      MED_INTERNAL_LNAME=34 , MED_INTERNAL_IDENT=38,
-	      MED_INTERNAL_CHAR=40  , MED_INTERNAL_UNDEF =0 } med_internal_type; /**< \internal */
+              MED_INTERNAL_INT8=20,
+              MED_INTERNAL_INT32=24 , MED_INTERNAL_INT64=26, MED_INTERNAL_INT=28,
+              MED_INTERNAL_NAME=30  , MED_INTERNAL_SNAME=32,
+              MED_INTERNAL_LNAME=34 , MED_INTERNAL_IDENT=38,
+              MED_INTERNAL_CHAR=40  , MED_INTERNAL_UNDEF =0 } med_internal_type; /**< \internal */
 
 /*TODO: Réécrire les routines _MEDatt avec med_internal_type au lieu de med_field_type */
 
-  typedef enum {MED_DOUBLE=MED_INTERNAL_FLOAT64,  /**<Type réel 64bits */
-		MED_FLOAT64=MED_INTERNAL_FLOAT64, /**<Type réel 64bits */
-		MED_FLOAT32=MED_INTERNAL_FLOAT32, /**<Type réel 32bits */
-		MED_INT32=MED_INTERNAL_INT32,     /**<Type entier 32bits */
-		MED_INT64=MED_INTERNAL_INT64,     /**<Type entier 64bits */
-		MED_INT=MED_INTERNAL_INT          /**<Type entier med_int dépendant de l'option de configuration --med-int */
-                                        }  med_field_type; 
+typedef enum {MED_DOUBLE=MED_INTERNAL_FLOAT64,  /**<Type réel 64bits */
+              MED_FLOAT64=MED_INTERNAL_FLOAT64, /**<Type réel 64bits */
+              MED_FLOAT32=MED_INTERNAL_FLOAT32, /**<Type réel 32bits */
+              MED_INT32=MED_INTERNAL_INT32,     /**<Type entier 32bits */
+              MED_INT64=MED_INTERNAL_INT64,     /**<Type entier 64bits */
+              MED_INT=MED_INTERNAL_INT          /**<Type entier med_int dépendant de l'option de configuration --med-int */
+             }  med_field_type; 
 
 typedef enum {MED_ATT_FLOAT64=MED_INTERNAL_FLOAT64,
-	      MED_ATT_INT=MED_INTERNAL_INT,
-	      MED_ATT_NAME=MED_INTERNAL_NAME,
-	      MED_ATT_UNDEF=MED_INTERNAL_UNDEF }  med_attribute_type; 
+              MED_ATT_INT=MED_INTERNAL_INT,
+              MED_ATT_NAME=MED_INTERNAL_NAME,
+              MED_ATT_UNDEF=MED_INTERNAL_UNDEF }  med_attribute_type; 
 
 typedef med_field_type med_parameter_type; 
 
 #define MED_ATT_FLOAT64_ctype   med_float       /**< \internal */
-#define MED_ATT_INT_ctype 	med_int         /**< \internal */
-#define MED_ATT_NAME_ctype 	char            /**< \internal */
-#define MED_ATT_UNDEF_ctype   	unknown_ctype   /**< \internal */
+#define MED_ATT_INT_ctype       med_int         /**< \internal */
+#define MED_ATT_NAME_ctype      char            /**< \internal */
+#define MED_ATT_UNDEF_ctype     unknown_ctype   /**< \internal */
 
 #define MED_CTYPE(medatttype) medatttype##_ctype 
 
 /* 2.3v3.0 ok : med_type_donnee*/
 typedef enum {MED_MESH, MED_FIELD, MED_LIBRARY, MED_FILE,
-	MED_MESH_SUPPORT,MED_ELSTRUCT, MED_FAMILY,MED_EQUIVALENCE, MED_GROUP, MED_JOINT, 
-	MED_LOCALIZATION, MED_PROFILE, MED_FILTER, MED_INTERPOLATION, MED_NUMERICAL_DATA,
-	MED_LINK, MED_CLASS_UNDEF=-1, MED_CLASS_ALL=-2 } med_class;
+        MED_MESH_SUPPORT,MED_ELSTRUCT, MED_FAMILY,MED_EQUIVALENCE, MED_GROUP, MED_JOINT, 
+        MED_LOCALIZATION, MED_PROFILE, MED_FILTER, MED_INTERPOLATION, MED_NUMERICAL_DATA,
+        MED_LINK, MED_FAMILY_ZERO, MED_FAMILY_NODE, MED_FAMILY_ELEM,
+        MED_CLASS_UNDEF=-1, MED_CLASS_ALL=-2 } med_class;
 
 
 typedef int med_geometry_type;
@@ -209,25 +218,25 @@ typedef int med_geometry_type;
 #define MED_QUAD8 208
 #define MED_QUAD9 209
 
-#define MED_TETRA4 304
-#define MED_PYRA5 305
-#define MED_PENTA6 306
-#define MED_HEXA8 308
+#define MED_TETRA4  304
+#define MED_PYRA5   305
+#define MED_PENTA6  306
+#define MED_HEXA8   308
 #define MED_TETRA10 310
-#define MED_OCTA12 312
-#define MED_PYRA13 313
+#define MED_OCTA12  312
+#define MED_PYRA13  313
 #define MED_PENTA15 315
 #define MED_PENTA18 318
-#define MED_HEXA20 320
-#define MED_HEXA27 327
+#define MED_HEXA20  320
+#define MED_HEXA27  327
 
 /* Mailles dont la géométrie à une connectivité variable*/
-#define MED_POLYGON 400
-#define MED_POLYGON2 420
+#define MED_POLYGON    400
+#define MED_POLYGON2   420
 #define MED_POLYHEDRON 500
 
 /* Mailles dont la géométrie est dynamique (découverte du modèle dans le fichier) */
-#define MED_STRUCT_GEO_INTERNAL 600
+#define MED_STRUCT_GEO_INTERNAL     600
 #define MED_STRUCT_GEO_SUP_INTERNAL 700
 
 #define MED_NONE 0
@@ -262,8 +271,8 @@ typedef enum {MED_CARTESIAN, MED_CYLINDRICAL, MED_SPHERICAL, MED_UNDEF_AXIS_TYPE
 typedef enum {MED_FALSE, MED_TRUE} med_bool ;
 
 #define MED_GAUSS_ELNO "MED_GAUSS_ELNO" /** < Localisation des points d'intégrations aux
-					     noeuds des élements. L'utilisation de cette
-					     localisation ne necessite pas sa création au préalable. */ 
+                                             noeuds des élements. L'utilisation de cette
+                                             localisation ne necessite pas sa création au préalable. */ 
 #define MED_IPOINT_ELNO MED_GAUSS_ELNO
 
 
@@ -281,40 +290,45 @@ typedef enum {MED_FALSE, MED_TRUE} med_bool ;
 #define MED_NO_IPOINT_INTERNAL 1       /**< \internal */
 
 #define MED_NO_PROFILE ""                     /**< Indique l'absence de profil. 
-						 Ce profil est équivalent à celui qui sélectionne 
-						 tous les éléments #MED_ALLENTITIES_PROFILE 
-						 \internal L'utilisation d'une chaine vide permet de tester rapidement la taille*/
+                                                 Ce profil est équivalent à celui qui sélectionne 
+                                                 tous les éléments #MED_ALLENTITIES_PROFILE 
+                                                 \internal L'utilisation d'une chaine vide permet de tester rapidement la taille*/
 
 #define MED_NO_GROUP ""                 /**< Indique l'absence de groupe dans la famille 0 */
 
 #define MED_ALLENTITIES_PROFILE MED_NO_PROFILE /**<Indique qu'il s'agit d'un profil qui selectionne toutes les entités.
-						  Ce profil est équivalent à #MED_NO_PROFILE . */	 
+                                                  Ce profil est équivalent à #MED_NO_PROFILE . */        
 
 
 #define MED_NO_PROFILE_INTERNAL   "MED_NO_PROFILE_INTERNAL"   /**< \internal*/
 #define MED_SAME_PROFILE_INTERNAL "MED_SAME_PROFILE_INTERNAL" /**< \internal*/
 
 #define MED_ALL_CONSTITUENT 0                 /**<Selectionne tous les constituants d'une valeur.
-						 Les constituants d'une valeur peuvent être les composantes
-						 des coordonnées des noeuds, les noeuds d'une connectivité nodal, 
-						 les composantes d'un champ. */
+                                                 Les constituants d'une valeur peuvent être les composantes
+                                                 des coordonnées des noeuds, les noeuds d'une connectivité nodal, 
+                                                 les composantes d'un champ. */
+#define MED_UNDEF_CONSTITUENT -1              /**<Valeur indéfinie pour electionner les constituants d'une valeur.
+                                                 Les constituants d'une valeur peuvent être les composantes
+                                                 des coordonnées des noeuds, les noeuds d'une connectivité nodal, 
+                                                 les composantes d'un champ. */
+
 #define MED_UNDEF_SIZE 0
 #define MED_NO_PROFILE_SIZE 0  /**<Fourni une valeur de taille de profil par défaut d'utilisation de la notion de profil.*/
 
 typedef enum {MED_SORT_DTIT,MED_SORT_ITDT,MED_SORT_UNDEF=-1 } med_sorting_type; /**<Indique l'ordre de tri des étapes de calcul d'un maillage.
                                                                                     Cette ordre, fixé à la création du maillage 
-										    est important pour comparer l'évolution du maillage
+                                                                                    est important pour comparer l'évolution du maillage
                                                                                     d'une étape de calcul à une autre.
-										    Utilisé conjointement avec les profils, 
-										    il permet de réduire les écritures aux 
-										    seules informations modifiées  par rapport 
-										    à l'étape de calcul précédente. */
+                                                                                    Utilisé conjointement avec les profils, 
+                                                                                    il permet de réduire les écritures aux 
+                                                                                    seules informations modifiées  par rapport 
+                                                                                    à l'étape de calcul précédente. */
 
-#define MED_ALL_DT -2 /**<Indique que l'on selectionne toutes les dates.*/
-#define MED_ALL_IT -2 /**<Indique que l'on selectionne toutes les itérations.*/
-#define MED_NO_DT -1 /**<Indique que l'on n'utilise pas la notion de date.*/
-#define MED_NO_IT -1 /**<Indique que l'on n'utilise pas la notion d'itération.*/
-#define MED_UNDEF_DT 0 /**<Fourni une valeur de date par défaut d'utilisation de la notion de date.*/
+#define MED_ALL_DT   -2 /**<Indique que l'on selectionne toutes les dates.*/
+#define MED_ALL_IT   -2 /**<Indique que l'on selectionne toutes les itérations.*/
+#define MED_NO_DT    -1 /**<Indique que l'on n'utilise pas la notion de date.*/
+#define MED_NO_IT    -1 /**<Indique que l'on n'utilise pas la notion d'itération.*/
+#define MED_UNDEF_DT  0 /**<Fourni une valeur de date par défaut d'utilisation de la notion de date.*/
 
 #define MED_ATT_NOT_FILLED -1
 
@@ -335,8 +349,23 @@ typedef float          med_float32;
 
 /*La ligne suivante est déterminée à l'étape de configuration*/
 typedef int  med_int; /**< La taille du med_int est paramétrable à l'étape de configuration de med fichier. */
-typedef int32_t  med_int32;     /**< L'entier med de taille fixe 32bits. */
-typedef int64_t  med_int64; /**< L'entier med  de taille fixe 64bits. */
+typedef int32_t  med_int32; /**< L'entier med de taille fixe 32bits. */
+typedef int64_t  med_int64; /**< L'entier med de taille fixe 64bits. */
+
+/** \struct med_path
+    \brief  Aggrégation de noms medfichier pour définir un chemin d'accès aux objets med de type class #med_class
+*/
+#define MED_MAX_NAME_IN_PATH 5
+#define MED_MAX_DATAGROUPNAME_IN_PATH 2*MED_MAX_NAME_IN_PATH*MED_NAME_SIZE /**< \2* for max internal intermediate groupname */
+
+typedef struct {
+  /*PUBLIC IN attributes*/
+  med_class           medclass;
+  med_int             nname;                      /**< \MEDfileObjectDescriptionPathRem2 */
+  const char *        name[MED_MAX_NAME_IN_PATH]; /**< \MEDfileObjectDescriptionPathRem2 */
+  /*PRIVATE attributes*/
+  char                _datagroupname[MED_MAX_DATAGROUPNAME_IN_PATH+1]; /** \internal*/
+} med_path;
 
 #define INIT2X( x ) x, x,
 #define INIT4X( x ) x, x, x, x
@@ -344,6 +373,10 @@ typedef int64_t  med_int64; /**< L'entier med  de taille fixe 64bits. */
 #define MED_MAX_FILTER_SPACES 4100
 #define MED_MAX_FILTER_SPACES_INIT {INIT4X(INIT10X(INIT10X(INIT10X(0)))), INIT10X(INIT10X(0)) }
 
+typedef enum {MED_FILTER_LIST       = 1,
+              MED_FILTER_BLOCK      = 2,
+              MED_FILTER_TYPE_UNDEF =-1 } med_filter_type; 
+
 /** \struct med_filter
     \brief  Filtre de sélection.
 */
@@ -352,23 +385,36 @@ typedef struct {
   med_int          nspaces;
   med_idt          memspace[MED_MAX_FILTER_SPACES];
   med_idt          diskspace[MED_MAX_FILTER_SPACES];
+  med_filter_type  filtertype;
   /*PUBLIC IN attributes*/
   med_int          nentity;
   med_int          nvaluesperentity;
   med_int          nconstituentpervalue;
   med_int          constituentselect;
   med_switch_mode  switchmode;
+  med_switch_mode  diskswitchmode;
+  /* Sélection par liste d'entités */
   med_int          filterarraysize;
+  const med_int *  filterarray;
   med_size*        filterarray23v30;
   med_int          profilearraysize;/*PRIVATE attribute en IN et OUT positionnée dans MEDfilterCr*/
+  /* profil utilisé et mode de stockage en mémoire */
   med_storage_mode storagemode;
   char             profilename[MED_NAME_SIZE+1];
+  /* Sélection par block d'entités */
+  med_size         start        ;
+  med_size         stride       ;
+  med_size         count        ;
+  med_size         blocksize    ;
+  med_size         lastblocksize;  
 } med_filter; 
 
 
-#define MED_FILTER_INIT { 0, MED_MAX_FILTER_SPACES_INIT, MED_MAX_FILTER_SPACES_INIT ,0,0,0,0,\
-                          MED_UNDEF_INTERLACE,MED_NO_FILTER_SIZE, NULL , \
-                          MED_NO_PROFILE_SIZE,MED_UNDEF_PFLMODE,MED_NO_PROFILE }
+#define MED_FILTER_INIT { 0, MED_MAX_FILTER_SPACES_INIT, MED_MAX_FILTER_SPACES_INIT,         \
+                          MED_FILTER_TYPE_UNDEF, 0, 0, 0, 0,				     \
+                          MED_UNDEF_INTERLACE,MED_UNDEF_INTERLACE,MED_NO_FILTER_SIZE,        \
+      NULL, NULL, MED_NO_PROFILE_SIZE,MED_UNDEF_PFLMODE,MED_NO_PROFILE,\
+                          0, 0, 0, 0, 0 }
 
 #define MED_NO_FILTER NULL
 #define MED_NO_FILTER_SIZE 0
@@ -386,16 +432,16 @@ typedef struct {
     \brief  Structure d'acceuil du buffer d'un fichier MED en mémoire.
 */
 typedef struct {
-  void *app_image_ptr; /**< Pointeur de l'emplacement contenant l'image mémoire au format MED */ 
-  size_t app_image_size; /**< La taille  de l'image mémoire*/
-  int ref_count; /**< Counteur de référence sur le nombre d'utilisation d'une image mémoire */
+  void   *app_image_ptr;  /**< Pointeur de l'emplacement contenant l'image mémoire au format MED */ 
+  size_t  app_image_size; /**< La taille  de l'image mémoire */
+  int     ref_count; /**< Compteur de référence sur le nombre d'utilisations d'une image mémoire */
 
-  void *fapl_image_ptr; /**< \internal Pointer to FAPL buffer */
-  size_t fapl_image_size;/**< \internal Size of FAPL buffer */
-  int fapl_ref_count; /**< \internal Reference counter for FAPL buffer */
-  void *vfd_image_ptr; /**< \internal Pointer to VFD buffer */
-  size_t vfd_image_size; /**< \internal Size of VFD buffer */
-  int vfd_ref_count; /**< \internal Reference counter for VFD buffer */
+  void           *fapl_image_ptr;  /**< \internal Pointer to FAPL buffer                */
+  size_t          fapl_image_size; /**< \internal Size of FAPL buffer                   */
+  int             fapl_ref_count;  /**< \internal Reference counter for FAPL buffer     */
+  void           *vfd_image_ptr;   /**< \internal Pointer to VFD buffer                 */
+  size_t          vfd_image_size;  /**< \internal Size of VFD buffer                    */
+  int             vfd_ref_count;   /**< \internal Reference counter for VFD buffer      */
   med_access_mode flags; /**< \internal Flags indicate how the file image will be open */
 } med_memfile ;
 
@@ -434,7 +480,8 @@ extern MEDC_EXPORT const med_geometry_type * const MED_GET_CELL_GEOMETRY_TYPE_FR
 extern MEDC_EXPORT const int MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT[MED_N_ENTITY_TYPES+2];
 
   
-/* Itérateurs sur les types d'entité et types géométriques */
+/* Itérateurs sur les types d'entité et types géométriques      */
+/* TODO : Ajouter un module de documentation pour ces fonctions */
 extern MEDC_EXPORT int                 MEDgetEntityTypeIt         (med_entity_type   entitytype);
 extern MEDC_EXPORT int                 MEDgetCellGeometryTypeIt   (med_geometry_type geotype   );
 extern MEDC_EXPORT int                 MEDgetFaceGeometryTypeIt   (med_geometry_type geotype   );
@@ -444,13 +491,14 @@ extern MEDC_EXPORT int                 MEDgetEntityGeometryTypeIt (med_entity_ty
 /**/
 extern MEDC_EXPORT const char * const  MEDgetGeometryTypeName     (med_geometry_type geotype   );
 extern MEDC_EXPORT const char * const  MEDgetEntityTypeName       (med_entity_type   entitytype);
+extern MEDC_EXPORT const char * const  MEDgetInterlacingModeName(med_interlacing_mode interlacing);
 
 /*      Predefined names for struct elements            */
 #define MED_PARTICLE_NAME   "MED_PARTICLE"
 #define MED_BALL_NAME       "MED_BALL"
 #define MED_BEAM_NAME       "MED_BEAM"
 
-/* 	Predefined attributes names for struct elements */
+/*      Predefined attributes names for struct elements */
 #define MED_PARTICLE_LABEL  "MED_PARTICLE_LABEL"
 #define MED_BALL_DIAMETER   "MED_BALL_DIAMETER"
 #define MED_BEAM_THICKNESS  "MED_BEAM_THICKNESS"
