@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2023  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2025  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -128,6 +128,7 @@
 #define MED_ERR_FILEVERSION -45
 #define MED_ERR_MEMFILE -46
 #define MED_ERR_CLASS -47
+#define MED_ERR_FILTERTYPE -48
 
 #define MED_ERR_FILE_MSG "du fichier "
 #define MED_ERR_MESH_MSG "du maillage "
@@ -179,6 +180,7 @@
 #define MED_ERR_FILEVERSION_MSG "de version de fichier"
 #define MED_ERR_MEMFILE_MSG "de fichier mémoire"
 #define MED_ERR_CLASS_MSG "du type d'objet MED"
+#define MED_ERR_FILTERTYPE_MSG "de type de filtre"
 
 /*COMPLEMENTS*/
 #define MED_ERR_VALUE_MSG "de valeur "
